# "fix" underlinking:
%define _disable_ld_no_undefined 1

Name:		ocaml-camlzip
Version:	1.10
Release:	%mkrel 7
Summary:        OCaml library for reading and writing zip, jar and gzip files
License:	LGPLv2 with exceptions
Group:		Development/OCaml
%global upver %(sed 's/\\.//' <<< %{version})
URL:            https://xavierleroy.org/software.html
Source0:        https://github.com/xavierleroy/camlzip/archive/rel%{upver}.tar.gz
BuildRequires:	make
BuildRequires:	ocaml >= 3.10.0
BuildRequires:	ocaml-compiler
BuildRequires:	ocaml-findlib
BuildRequires:	ocaml-ocamldoc
BuildRequires:	pkgconfig(zlib)

Provides:	ocaml-zip = %{version}-%{release}
Provides:	ocaml-zip%{?_isa} = %{version}-%{release}

%description
This Objective Caml library provides easy access to compressed files in ZIP
and GZIP format, as well as to Java JAR files. It provides functions for
reading from and writing to compressed files in these formats.

%package	devel
Summary:	Development files for %{name}
Group:		Development/OCaml
Requires:	pkgconfig(zlib)
Requires:	%{name}%{?_isa} = %{version}-%{release}
Provides:	ocaml-zip-devel = %{version}-%{release}
Provides:	ocaml-zip-devel%{?_isa} = %{version}-%{release}

%description devel
This package contains the development files needed to build applications
using %{name}.

%prep
%autosetup -n camlzip-rel%{upver}

# Do not try to overwrite the system ld.conf
sed -i "s,ocamlfind install,& -ldconf $PWD/ld.conf," Makefile

# The META file has the wrong version number
sed -i 's/1\.09/%{version}/' META-zip

%build
%make_build depend
%make_build all
%make_build allopt
mkdir -p doc
ocamldoc -colorize-code -html gzip.mli zip.mli zlib.mli -d doc

# Relink the stublibs with $RPM_LD_FLAGS.
ocamlmklib -g -ldopt "$RPM_LD_FLAGS" -lz -o camlzip $(ar t libcamlzip.a)

%install
export DESTDIR=%{buildroot}
export OCAMLFIND_DESTDIR=%{buildroot}/%{_libdir}/ocaml
export DLLDIR=$OCAMLFIND_DESTDIR/stublibs
export EXT_DLL=.so
install -d -m 755 $OCAMLFIND_DESTDIR/stublibs
install -d -m 755 $OCAMLFIND_DESTDIR/zip
touch ld.conf
make install-findlib

%check
export LD_LIBRARY_PATH=$PWD
make -C test
test/testzlib Makefile Makefile.gz
test/testzlib -d Makefile.gz Makefile.uncompressed
cmp Makefile Makefile.uncompressed

%files
%doc LICENSE README Changes
%dir %{_libdir}/ocaml/zip
%{_libdir}/ocaml/zip/*.cmi
%{_libdir}/ocaml/zip/*.cma
%{_libdir}/ocaml/zip/META
%{_libdir}/ocaml/camlzip/META
%{_libdir}/ocaml/stublibs/dllcamlzip.so*

%files devel
%doc test doc
%{_libdir}/ocaml/zip/*.a
%{_libdir}/ocaml/zip/*.cmx*
%{_libdir}/ocaml/zip/*.mli


%changelog
* Fri Mar 31 2023 daviddavid <daviddavid> 1.10-7.mga9
+ Revision: 1951057
- fix a typo in previous commit

* Fri Mar 31 2023 daviddavid <daviddavid> 1.10-6.mga9
+ Revision: 1951051
- add more virtual provides with %%{?_isa}

* Wed May 18 2022 pterjan <pterjan> 1.10-5.mga9
+ Revision: 1858757
- Rebuild for OCaml 4.14

* Tue Mar 29 2022 umeabot <umeabot> 1.10-4.mga9
+ Revision: 1832422
- Mageia 9 Mass Rebuild

* Tue Oct 12 2021 tv <tv> 1.10-3.mga9
+ Revision: 1750685
+ rebuild (emptylog)

* Tue Oct 12 2021 tv <tv> 1.10-2.mga9
+ Revision: 1750673
- Rebuild for ocaml 4.13.1

* Thu Mar 04 2021 tv <tv> 1.10-1.mga9
+ Revision: 1698450
- 1.10

* Wed Mar 03 2021 tv <tv> 1.07-10.mga9
+ Revision: 1696533
- rebuild for ocaml-4.2-12

* Sat Aug 22 2020 tv <tv> 1.07-9.mga8
+ Revision: 1617870
- Rebuild for new ocaml deps generator

* Fri Feb 28 2020 umeabot <umeabot> 1.07-8.mga8
+ Revision: 1551136
- Rebuild for ocaml 4.10.0 final

* Wed Feb 19 2020 umeabot <umeabot> 1.07-7.mga8
+ Revision: 1543242
- Mageia 8 Mass Rebuild

* Sun Jan 19 2020 tv <tv> 1.07-6.mga8
+ Revision: 1481532
- rebuild for ocaml-4.10

* Tue Oct 23 2018 tv <tv> 1.07-5.mga7
+ Revision: 1324040
- rebuild with ocaml-4.07.1

* Mon Oct 22 2018 pterjan <pterjan> 1.07-4.mga7
+ Revision: 1323728
- Rebuild for ocaml 4.07

* Sun Sep 23 2018 umeabot <umeabot> 1.07-3.mga7
+ Revision: 1299848
- Mageia 7 Mass Rebuild

* Fri Mar 23 2018 pterjan <pterjan> 1.07-2.mga7
+ Revision: 1211579
- Workaround parallel build problem

* Sun Nov 26 2017 tv <tv> 1.07-1.mga7
+ Revision: 1179307
- new release
- new site
- rebuild for new ocaml

* Thu Oct 12 2017 daviddavid <daviddavid> 1.05-9.mga7
+ Revision: 1171342
- patch3: use standard ISO C99 types uint{32,64}_t

* Mon Sep 26 2016 pterjan <pterjan> 1.05-8.mga6
+ Revision: 1056272
- Rebuild for fix in ocaml

* Mon Feb 01 2016 pterjan <pterjan> 1.05-7.mga6
+ Revision: 930817
- Rebuild for new ocaml

* Wed Oct 15 2014 umeabot <umeabot> 1.05-6.mga5
+ Revision: 746372
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.05-5.mga5
+ Revision: 683003
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 1.05-4.mga4
+ Revision: 536412
- Mageia 4 Mass Rebuild

* Mon Sep 23 2013 blue_prawn <blue_prawn> 1.05-3.mga4
+ Revision: 484222
- rebuild for ocaml-4.01.0

* Sat Jan 12 2013 umeabot <umeabot> 1.05-2.mga3
+ Revision: 361206
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Nov 20 2012 blue_prawn <blue_prawn> 1.05-1.mga3
+ Revision: 319811
- updated to last version 1.05

* Mon Oct 01 2012 blue_prawn <blue_prawn> 1.04-10.mga3
+ Revision: 301642
- new rpm group for ocaml
- new rpm group for ocaml
- update to new ocamlforge location for the homepage
- update to new ocamlforge location

* Sun Oct 02 2011 fwang <fwang> 1.04-8.mga2
+ Revision: 150881
- rebuild for new ocaml

* Fri Apr 08 2011 ennael <ennael> 1.04-7.mga1
+ Revision: 82385
- clean spec file
- imported package ocaml-camlzip


* Thu Sep 10 2009 Florent Monnier <blue_prawn@mandriva.org> 1.04-7mdv2010.0
+ Revision: 436253
- rebuild
- consistency naming with Debian and Fedora

* Sat Aug 22 2009 Florent Monnier <blue_prawn@mandriva.org> 1.04-6mdv2010.0
+ Revision: 419718
- increm mkrel
- corrected the license field

* Sat Aug 22 2009 Florent Monnier <blue_prawn@mandriva.org> 1.04-5mdv2010.0
+ Revision: 419580
- patch for plain_uncompress function from debian by Sven Luther
- added a patch for the makefile of the tests
- added test dir, with patched makefile (patch from debian by Samuel Mimram)
  generating html doc

* Sat Aug 22 2009 Florent Monnier <blue_prawn@mandriva.org> 1.04-4mdv2010.0
+ Revision: 419488
- added missing files zlib.cmi / zlib.mli
  modified the install dir, to align on fedora, debian and upstream

* Sat Jun 27 2009 Guillaume Rousse <guillomovitch@mandriva.org> 1.04-3mdv2010.0
+ Revision: 389923
- rebuild

* Thu Jan 08 2009 Guillaume Rousse <guillomovitch@mandriva.org> 1.04-2mdv2009.1
+ Revision: 327123
- site-lib hierarchy doesn't exist anymore

  + Florent Monnier <blue_prawn@mandriva.org>
    - findlib package name

* Sun Dec 21 2008 Guillaume Rousse <guillomovitch@mandriva.org> 1.04-1mdv2009.1
+ Revision: 317101
- new version
- move all non-devel files into main package (Florent Monnier <fmonnier@linux-nantes.org>)

* Tue Dec 09 2008 Pixel <pixel@mandriva.com> 1.03-8mdv2009.1
+ Revision: 312252
- rebuild

* Wed Jul 30 2008 Thierry Vignaud <tv@mandriva.org> 1.03-7mdv2009.0
+ Revision: 254187
- rebuild

* Tue Mar 04 2008 Guillaume Rousse <guillomovitch@mandriva.org> 1.03-5mdv2008.1
+ Revision: 178364
- rebuild

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Sat Sep 01 2007 Guillaume Rousse <guillomovitch@mandriva.org> 1.03-4mdv2008.0
+ Revision: 77659
- drop macro definition, now in rpm-mandriva-setup
  ship .cmi file in non-devel subpackage

* Fri Jun 22 2007 Per Øyvind Karlsen <peroyvind@mandriva.org> 1.03-3mdv2008.0
+ Revision: 43333
- build 'allopt' too

* Tue Jun 19 2007 Per Øyvind Karlsen <peroyvind@mandriva.org> 1.03-2mdv2008.0
+ Revision: 41275
- rebuild

* Fri Apr 27 2007 Guillaume Rousse <guillomovitch@mandriva.org> 1.03-1mdv2008.0
+ Revision: 18545
- Import ocaml-camlzip



* Thu Apr 26 2007 Guillaume Rousse <guillomovitch@mandriva.org> 1.03-1mdv2008.0
- first mdv release
